This crate provides a web application for translating different formats to Nix.
Supported Formats
See any2nix::Format for an enumeration of supported formats.
Each format is gated behind its own feature.
The default feature enables all formats.
Crate Features
Besides the features for each format, this crate also exposes the following features:
api: Enables an “/api” endpoint for interaction without a browser through [any2nix-api].trace: Enables tracing of incoming HTTP requests through [tower-http] and [tracing].utoipa: Enables OpenAPI schema generation through [utoipa].utoipa-swagger-ui: Enables the Swagger UI for the API through [utoipa-swagger-ui].